var path = require('path')
var webpack = require('webpack')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const url = path.resolve(__dirname, './index.html');
function resolve (dir) {
    return path.join(__dirname, '..', dir)
}
module.exports = {
  devtool: 'source-map',
  entry: './src/packages/index.js',
  output: {
    path: path.resolve(__dirname, './dist'),
    // publicPath: '/dist',
    filename: "bundle.js",
    libraryTarget: 'umd',
    umdNamedDefine: true
  },
  module: {
    rules: [
        {
            test: /\.less$/,
            use: [
                { loader: "style-loader" },
                { loader: "css-loader" },
                { loader: "postcss-loader" },
                { loader: "less-loader" }
            ]
        },
        {
            test: /\.css$/,
            use: [
                { loader: "style-loader" },
                { loader: "css-loader" },
                { loader: "postcss-loader" }
            ]
        },
        {
        test: /\.vue$/,
        loader: 'vue-loader',
        options: {
          loaders: {
          }
          // other vue-loader options go here
        }
      },
        {
            test: /\.(vtpl)$/,
            loader: "vue-template-loader",
            options: {
                // scoped: true,
                transformAssetUrls: {
                    // The key should be an element name
                    img: 'src'
                }
            }
        },
      {
        test: /\.js$/,
        loader: 'babel-loader',
        exclude: /node_modules/
      },
      {
        test: /\.(png|jpg|gif|svg)$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]?[hash]'
        }
      }
    ]
  },
    plugins:[
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: url,
            inject: true
        }),
    ],
  resolve: {
    alias: {
      'vue$': 'vue/dist/vue.esm.js',
      '@': resolve('src'),
    },
    extensions: ['.js', '.vue', '.json','*']
  },
  devServer: {
    historyApiFallback: true,
    noInfo: false,
    overlay: true
  },
  performance: {
    hints: false
  },
  devtool: '#eval-source-map'
}

if (process.env.NODE_ENV === 'production') {
  module.exports.devtool = '#source-map'
  // http://vue-loader.vuejs.org/en/workflow/production.html
  module.exports.plugins = (module.exports.plugins || []).concat([
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"production"'
      }
    }),
    new webpack.optimize.UglifyJsPlugin({
      sourceMap: true,
      compress: {
        warnings: false
      }
    }),
    new webpack.LoaderOptionsPlugin({
      minimize: true
    })
  ])
}
